abstract class ShopEvent {}

class LoadShopEvent extends ShopEvent {}

class BuyCardEvent extends ShopEvent {
  final String cardId;
  BuyCardEvent(this.cardId);
}

class SelectCardEvent extends ShopEvent {
  final String cardId;
  SelectCardEvent(this.cardId);
}

class PurchaseEvent extends ShopEvent {
  final String kind;
  final String productId;
  PurchaseEvent(this.kind, this.productId);
}

class AdRewardEvent extends ShopEvent {}
